<?php

namespace IQBall\Core\Model;

use IQBall\Core\Gateway\TacticInfoGateway;
use IQBall\Core\Validation\ValidationFail;
use IQBall\Core\Data\TacticInfo;

class TacticModel {
    public const TACTIC_DEFAULT_NAME = "Nouvelle tactique";


    private TacticInfoGateway $tactics;

    /**
     * @param TacticInfoGateway $tactics
     */
    public function __construct(TacticInfoGateway $tactics) {
        $this->tactics = $tactics;
    }

    /**
     * creates a new empty tactic, with given name
     * @param string $name
     * @param int $ownerId
     * @return TacticInfo
     */
    public function makeNew(string $name, int $ownerId): TacticInfo {
        return $this->tactics->insert($name, $ownerId);
    }

    /**
     * creates a new empty tactic, with a default name
     * @param int $ownerId
     * @return TacticInfo|null
     */
    public function makeNewDefault(int $ownerId): ?TacticInfo {
        return $this->makeNew(self::TACTIC_DEFAULT_NAME, $ownerId);
    }

    /**
     * Tries to retrieve information about a tactic
     * @param int $id tactic identifier
     * @return TacticInfo|null or null if the identifier did not match a tactic
     */
    public function get(int $id): ?TacticInfo {
        return $this->tactics->get($id);
    }

    /**
     * Return the nb last tactics created
     *
     * @param integer $nb
     * @return array<array<string,mixed>>
     */
    public function getLast(int $nb): ?array {
        return $this->tactics->getLast($nb);
    }

    /**
     * Update the name of a tactic
     * @param int $id the tactic identifier
     * @param string $name the new name to set
     * @return ValidationFail[] failures, if any
     */
    public function updateName(int $id, string $name, int $authId): array {

        $tactic = $this->tactics->get($id);

        if ($tactic == null) {
            return [ValidationFail::notFound("Could not find tactic")];
        }

        if ($tactic->getOwnerId() != $authId) {
            return [ValidationFail::unauthorized()];
        }

        $this->tactics->updateName($id, $name);
        return [];
    }

}
